@@ -34,6 +34,7 @@ class NodeNetworkState(Resource):
         self.desired_state = status.get("desiredState", {"interfaces": []})
 
     def set_interface(self, interface):
+
         # First drop the interface is's already in the list
         interfaces = [
             iface
@@ -59,11 +60,12 @@ class NodeNetworkState(Resource):
             )
 
     def apply(self):
+        resource = self.to_dict()
         retries_on_conflict = 3
         while True:
             try:
-                self.res["metadata"] = self.instance.to_dict()["metadata"]
-                self.update(self.res)
+                resource["metadata"] = self.instance.to_dict()["metadata"]
+                self.update(resource)
                 break
             except ConflictError as e:
                 retries_on_conflict -= 1
